@@ -87,6 +87,11 @@ pub fn get_config() -> (Config, usize) {
                 .help("standart, json, url, request (default is \"standart\")")
                 .takes_value(true)
         )
+        .arg(
+            Arg::with_name("append")
+                .long("append")
+                .help("Append to the output file instead of overwriting it.")
+        )
         .arg(
             Arg::with_name("method")
                 .short("X")
@@ -213,7 +218,7 @@ pub fn get_config() -> (Config, usize) {
         .arg(
             Arg::with_name("value_size")
                 .long("value-size")
-                .help("Custom value size. Affects {{random}} variables as well (default is 5)")
+                .help("Custom value size. Affects {{random}} variables as well (default is 7)")
                 .takes_value(true)
         )
         .arg(
@@ -245,6 +250,11 @@ pub fn get_config() -> (Config, usize) {
             Arg::with_name("verify")
                 .long("verify")
                 .help("Verify found parameters one more time.")
+        )
+        .arg(
+            Arg::with_name("reflected_only")
+                .long("reflected-only")
+                .help("Disable page comparison and search for reflected parameters only.")
         );
 
     let args = app.clone().get_matches();
@@ -288,7 +298,7 @@ pub fn get_config() -> (Config, usize) {
             }
         },
         None => {
-            5
+            7
         }
     };
 
@@ -538,6 +548,7 @@ pub fn get_config() -> (Config, usize) {
         output_file: args.value_of("output").unwrap_or("").to_string(),
         save_responses: args.value_of("save-responses").unwrap_or("").to_string(),
         output_format: args.value_of("output-format").unwrap_or("").to_string(),
+        append: args.is_present("append"),
         as_body: args.is_present("as-body"),
         headers_discovery: args.is_present("headers-discovery"),
         within_headers,
@@ -557,7 +568,8 @@ pub fn get_config() -> (Config, usize) {
         max,
         concurrency,
         http2: args.is_present("http2"),
-        verify: args.is_present("verify")
+        verify: args.is_present("verify"),
+        reflected_only: args.is_present("reflected_only")
     };
 
     config = if !request.is_empty() {
